( cd usr/lib ; rm -rf libruby.so )
( cd usr/lib ; ln -sf libruby.so.1.9.1 libruby.so )
( cd usr/lib ; rm -rf libruby.so.1.9 )
( cd usr/lib ; ln -sf libruby.so.1.9.1 libruby.so.1.9 )
